icsemantic.catalog

Package platecom :: Package ontocatalog |
[hide private]
[frames] | no frames]

# Package ontocatalog

source code

OntoCatalog

Submodules | [hide private]
icsemantic.catalog.Extensions icsemantic.catalog.Extensions.install: Install the product. icsemantic.catalog.config: Global constants for OntoCatalog. icsemantic.catalog.criteria: In this module defines three criteria content types for ATTopic to match the catalog indexes defined in the 'indexes' module. icsemantic.catalog.criteria.related: A friendly criterion for ATTopic that matches the SearchableRelatedText index parameters icsemantic.catalog.criteria.synonym: A friendly criterion for ATTopic that matches the SearchableSynonymousText index parameters. icsemantic.catalog.criteria.translation: A friendly criterion for ATTopic that matches the SearchableTranslatedText index parameters. icsemantic.catalog.indexes: This package implements three new indexes for the portal catalog. icsemantic.catalog.indexes.related: RelatedIndex is an index for the catalog that does not index anything. icsemantic.catalog.indexes.synonym: SynonymIndex is an index for the catalog that does not index anything. icsemantic.catalog.indexes.translation: TranslationIndex is an index for the catalog that does not index anything. icsemantic.catalog.indexes.utils: A few common pieces of code used in the catalog indexes in this package are grouped into functions in this module to make its reuse easier. icsemantic.catalog.setuphandlers: This module handles the product install process. icsemantic.catalog.tests: Automated unit, functional and integration tests for OntoCatalog. icsemantic.catalog.tests.base: Test setup for unit, integration and functional tests. icsemantic.catalog.tests.test_functional: Functional tests for OntoCatalog. icsemantic.catalog.tests.test_indexes: Test the catalog indexes added by OntoCatalog. icsemantic.catalog.tests.test_setup: Test OntoCatalog setup on installation.

Functions | [hide private]
initialize(context) Initialize the package | source code
_catalog_search_defaults(context, request, args) Ignore the Language keyword when we are looking for translations or related content. | source code
replace_catalog(context) Make _catalog_search_defaults provide IQueryDefaults so pluggablecatalog uses it for the default search paramenters for all catalog searches. | source code
register_fake_index(context) Register indexes | source code

Variables | [hide private]
| OntoCatalogMessageFactory = `MessageFactory('platecom.ontocatal`...``

Variables Details | [hide private]

  ### OntoCatalogMessageFactory Value:
      MessageFactory('icsemantic.catalog')